==> surveyplat-proof-common-zjgg-1.0.0-20191013.075046-12-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzJztb.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2018/5/2.
 * 举证图斑表
 */
@Table(name = "dcjz_jztb")
public class DcjzJztb {

    @Id
    //举证图斑ID
    private String jztbid;
    //项目名称
    private String xmmc;
    //行政区代码
    private String xzqdm;
    //行政区名称
    private String xzqmc;
    //图斑编号
    private String tbbh;
    //图斑面积
    private Float tbmj;
    //耕地面积
    private Float gdmj;
    //林地面积
    private Float ldmj;
    //是否已纳入生态红线
    private String sfynrsthx;
    //林地备注
    private String ldbz;
    //草地果园面积
    private Float cdgymj;
    //是否破坏耕作层
    private String sfphgzc;
    //草地果园备注
    private String cdgybz;
    //挖塘养鱼面积
    private Float wtyymj;
    //挖塘养鱼备注
    private String wtyybz;
    //水深不深
    private String ssbs;
    //提水养殖面积
    private Float tsyzmj;
    //设施占用类型
    private String sszylx;
    //合法永久建设面积（设施农用地）
    private Float sshfyjjsmj;
    //非法永久建设面积（设施农用地）
    private Float ssffyjjsmj;
    //建设占用类型
    private String jszylx;
    //合法永久建设面积（建设占用）
    private Float hfyjjsmj;
    //非法永久建设面积（建设占用）
    private Float ffyjjsmj;
    //临时用地占用面积（建设占用）
    private Float lsydzymj;
    //建设占用备注
    private String jszybz;
    //灾毁耕地面积
    private Float zhgdmj;
    //灾毁原因
    private String zhyy;
    //灾毁耕地备注
    private String zhgdbz;
    //光伏用地面积
    private Float gfydmj;
    //光伏板高度
    private Float gfbgd;
    //光伏用地备注
    private String gfydbz;
    //其他用地面积
    private Float qtydmj;
    //其他用地备注
    private String qtydbz;
    //土地座落村名称
    private String tdzlcun;
    //土地座落镇名称
    private String tdzlxz;
    //中心点X坐标
    private String xzb;
    //中心点Y坐标
    private String yzb;
    //经度
    private Double jd;
    //纬度
    private Double wd;
    //时相
    private Date sx;
    //图形WKB
    private byte[] txwkb;
    //图形
    private String tx;
    //影像截图路径
    private String yxlj;
    //地块举证状态
    private String dkjzzt;
    //举证人员
    private String jzry;
    //举证时间
    private Date jzsj;
    //举证签名
    private byte[] jzqm;
    //是否需要外业
    private String sfwy;
    //图斑排序
    private Integer tbpx;
    //备注
    private String bz;
    //问题备注
    private String wtbz;
    //项目数据来源
    private String xmsjly;
    //核查结果类型
    private String hcjglx;

    public String getHcjglx() {
        return hcjglx;
    }

    public void setHcjglx(String hcjglx) {
        this.hcjglx = hcjglx;
    }

    public String getJztbid() {
        return jztbid;
    }

    public void setJztbid(String jztbid) {
        this.jztbid = jztbid;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getTbbh() {
        return tbbh;
    }

    public void setTbbh(String tbbh) {
        this.tbbh = tbbh;
    }

    public Float getTbmj() {
        return tbmj;
    }

    public void setTbmj(Float tbmj) {
        this.tbmj = tbmj;
    }

    public Float getGdmj() {
        return gdmj;
    }

    public void setGdmj(Float gdmj) {
        this.gdmj = gdmj;
    }

    public Float getLdmj() {
        return ldmj;
    }

    public void setLdmj(Float ldmj) {
        this.ldmj = ldmj;
    }

    public String getSfynrsthx() {
        return sfynrsthx;
    }

    public void setSfynrsthx(String sfynrsthx) {
        this.sfynrsthx = sfynrsthx;
    }

    public String getLdbz() {
        return ldbz;
    }

    public void setLdbz(String ldbz) {
        this.ldbz = ldbz;
    }

    public Float getCdgymj() {
        return cdgymj;
    }

    public void setCdgymj(Float cdgymj) {
        this.cdgymj = cdgymj;
    }

    public String getSfphgzc() {
        return sfphgzc;
    }

    public void setSfphgzc(String sfphgzc) {
        this.sfphgzc = sfphgzc;
    }

    public String getCdgybz() {
        return cdgybz;
    }

    public void setCdgybz(String cdgybz) {
        this.cdgybz = cdgybz;
    }

    public Float getWtyymj() {
        return wtyymj;
    }

    public void setWtyymj(Float wtyymj) {
        this.wtyymj = wtyymj;
    }

    public String getWtyybz() {
        return wtyybz;
    }

    public void setWtyybz(String wtyybz) {
        this.wtyybz = wtyybz;
    }

    public String getSsbs() {
        return ssbs;
    }

    public void setSsbs(String ssbs) {
        this.ssbs = ssbs;
    }

    public Float getTsyzmj() {
        return tsyzmj;
    }

    public void setTsyzmj(Float tsyzmj) {
        this.tsyzmj = tsyzmj;
    }

    public String getSszylx() {
        return sszylx;
    }

    public void setSszylx(String sszylx) {
        this.sszylx = sszylx;
    }

    public Float getSshfyjjsmj() {
        return sshfyjjsmj;
    }

    public void setSshfyjjsmj(Float sshfyjjsmj) {
        this.sshfyjjsmj = sshfyjjsmj;
    }

    public Float getSsffyjjsmj() {
        return ssffyjjsmj;
    }

    public void setSsffyjjsmj(Float ssffyjjsmj) {
        this.ssffyjjsmj = ssffyjjsmj;
    }

    public String getJszylx() {
        return jszylx;
    }

    public void setJszylx(String jszylx) {
        this.jszylx = jszylx;
    }

    public Float getHfyjjsmj() {
        return hfyjjsmj;
    }

    public void setHfyjjsmj(Float hfyjjsmj) {
        this.hfyjjsmj = hfyjjsmj;
    }

    public Float getFfyjjsmj() {
        return ffyjjsmj;
    }

    public void setFfyjjsmj(Float ffyjjsmj) {
        this.ffyjjsmj = ffyjjsmj;
    }

    public Float getLsydzymj() {
        return lsydzymj;
    }

    public void setLsydzymj(Float lsydzymj) {
        this.lsydzymj = lsydzymj;
    }

    public String getJszybz() {
        return jszybz;
    }

    public void setJszybz(String jszybz) {
        this.jszybz = jszybz;
    }

    public Float getZhgdmj() {
        return zhgdmj;
    }

    public void setZhgdmj(Float zhgdmj) {
        this.zhgdmj = zhgdmj;
    }

    public String getZhyy() {
        return zhyy;
    }

    public void setZhyy(String zhyy) {
        this.zhyy = zhyy;
    }

    public String getZhgdbz() {
        return zhgdbz;
    }

    public void setZhgdbz(String zhgdbz) {
        this.zhgdbz = zhgdbz;
    }

    public Float getGfydmj() {
        return gfydmj;
    }

    public void setGfydmj(Float gfydmj) {
        this.gfydmj = gfydmj;
    }

    public Float getGfbgd() {
        return gfbgd;
    }

    public void setGfbgd(Float gfbgd) {
        this.gfbgd = gfbgd;
    }

    public String getGfydbz() {
        return gfydbz;
    }

    public void setGfydbz(String gfydbz) {
        this.gfydbz = gfydbz;
    }

    public Float getQtydmj() {
        return qtydmj;
    }

    public void setQtydmj(Float qtydmj) {
        this.qtydmj = qtydmj;
    }

    public String getQtydbz() {
        return qtydbz;
    }

    public void setQtydbz(String qtydbz) {
        this.qtydbz = qtydbz;
    }

    public String getTdzlcun() {
        return tdzlcun;
    }

    public void setTdzlcun(String tdzlcun) {
        this.tdzlcun = tdzlcun;
    }

    public String getTdzlxz() {
        return tdzlxz;
    }

    public void setTdzlxz(String tdzlxz) {
        this.tdzlxz = tdzlxz;
    }

    public String getXzb() {
        return xzb;
    }

    public void setXzb(String xzb) {
        this.xzb = xzb;
    }

    public String getYzb() {
        return yzb;
    }

    public void setYzb(String yzb) {
        this.yzb = yzb;
    }

    public Double getJd() {
        return jd;
    }

    public void setJd(Double jd) {
        this.jd = jd;
    }

    public Double getWd() {
        return wd;
    }

    public void setWd(Double wd) {
        this.wd = wd;
    }

    public Date getSx() {
        return sx;
    }

    public void setSx(Date sx) {
        this.sx = sx;
    }

    public byte[] getTxwkb() {
        return txwkb;
    }

    public void setTxwkb(byte[] txwkb) {
        this.txwkb = txwkb;
    }

    public String getTx() {
        return tx;
    }

    public void setTx(String tx) {
        this.tx = tx;
    }

    public String getYxlj() {
        return yxlj;
    }

    public void setYxlj(String yxlj) {
        this.yxlj = yxlj;
    }

    public String getDkjzzt() {
        return dkjzzt;
    }

    public void setDkjzzt(String dkjzzt) {
        this.dkjzzt = dkjzzt;
    }

    public String getJzry() {
        return jzry;
    }

    public void setJzry(String jzry) {
        this.jzry = jzry;
    }

    public Date getJzsj() {
        return jzsj;
    }

    public void setJzsj(Date jzsj) {
        this.jzsj = jzsj;
    }

    public byte[] getJzqm() {
        return jzqm;
    }

    public void setJzqm(byte[] jzqm) {
        this.jzqm = jzqm;
    }

    public String getSfwy() {
        return sfwy;
    }

    public void setSfwy(String sfwy) {
        this.sfwy = sfwy;
    }

    public Integer getTbpx() {
        return tbpx;
    }

    public void setTbpx(Integer tbpx) {
        this.tbpx = tbpx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getWtbz() {
        return wtbz;
    }

    public void setWtbz(String wtbz) {
        this.wtbz = wtbz;
    }

    public String getXmsjly() {
        return xmsjly;
    }

    public void setXmsjly(String xmsjly) {
        this.xmsjly = xmsjly;
    }
}

==> surveyplat-proof-common-zjgg-1.0.0-20191022.095956-20-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzJztb.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2018/5/2.
 * 举证图斑表
 */
@Table(name = "dcjz_jztb")
public class DcjzJztb {

    @Id
    //举证图斑ID
    private String jztbid;
    //项目名称
    private String xmmc;
    //行政区代码
    private String xzqdm;
    //行政区名称
    private String xzqmc;
    //图斑编号
    private String tbbh;
    //图斑面积
    private Float tbmj;
    //耕地面积
    private Float gdmj;
    //林地面积
    private Float ldmj;
    //是否已纳入生态红线
    private String sfynrsthx;
    //林地备注
    private String ldbz;
    //草地果园面积
    private Float cdgymj;
    //是否破坏耕作层
    private String sfphgzc;
    //草地果园备注
    private String cdgybz;
    //挖塘养鱼面积
    private Float wtyymj;
    //挖塘养鱼备注
    private String wtyybz;
    //水深不深
    private String ssbs;
    //提水养殖面积
    private Float tsyzmj;
    //设施占用类型
    private String sszylx;
    //合法永久建设面积（设施农用地）
    private Float sshfyjjsmj;
    //非法永久建设面积（设施农用地）
    private Float ssffyjjsmj;
    //建设占用类型
    private String jszylx;
    //合法永久建设面积（建设占用）
    private Float hfyjjsmj;
    //非法永久建设面积（建设占用）
    private Float ffyjjsmj;
    //临时用地占用面积（建设占用）
    private Float lsydzymj;
    //建设占用备注
    private String jszybz;
    //灾毁耕地面积
    private Float zhgdmj;
    //灾毁原因
    private String zhyy;
    //灾毁耕地备注
    private String zhgdbz;
    //光伏用地面积
    private Float gfydmj;
    //光伏板高度
    private Float gfbgd;
    //光伏用地备注
    private String gfydbz;
    //其他用地面积
    private Float qtydmj;
    //其他用地备注
    private String qtydbz;
    //土地座落村名称
    private String tdzlcun;
    //土地座落镇名称
    private String tdzlxz;
    //中心点X坐标
    private String xzb;
    //中心点Y坐标
    private String yzb;
    //经度
    private Double jd;
    //纬度
    private Double wd;
    //时相
    private Date sx;
    //图形WKB
    private byte[] txwkb;
    //图形
    private String tx;
    //影像截图路径
    private String yxlj;
    //地块举证状态
    private String dkjzzt;
    //举证人员
    private String jzry;
    //举证时间
    private Date jzsj;
    //举证签名
    private byte[] jzqm;
    //是否需要外业
    private String sfwy;
    //图斑排序
    private Integer tbpx;
    //备注
    private String bz;
    //问题备注
    private String wtbz;
    //项目数据来源
    private String xmsjly;
    //核查结果类型
    private String hcjglx;
    //地块计算面积
    private Float dkjsmj;

    public Float getDkjsmj() {
        return dkjsmj;
    }

    public void setDkjsmj(Float dkjsmj) {
        this.dkjsmj = dkjsmj;
    }

    public String getHcjglx() {
        return hcjglx;
    }

    public void setHcjglx(String hcjglx) {
        this.hcjglx = hcjglx;
    }

    public String getJztbid() {
        return jztbid;
    }

    public void setJztbid(String jztbid) {
        this.jztbid = jztbid;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getTbbh() {
        return tbbh;
    }

    public void setTbbh(String tbbh) {
        this.tbbh = tbbh;
    }

    public Float getTbmj() {
        return tbmj;
    }

    public void setTbmj(Float tbmj) {
        this.tbmj = tbmj;
    }

    public Float getGdmj() {
        return gdmj;
    }

    public void setGdmj(Float gdmj) {
        this.gdmj = gdmj;
    }

    public Float getLdmj() {
        return ldmj;
    }

    public void setLdmj(Float ldmj) {
        this.ldmj = ldmj;
    }

    public String getSfynrsthx() {
        return sfynrsthx;
    }

    public void setSfynrsthx(String sfynrsthx) {
        this.sfynrsthx = sfynrsthx;
    }

    public String getLdbz() {
        return ldbz;
    }

    public void setLdbz(String ldbz) {
        this.ldbz = ldbz;
    }

    public Float getCdgymj() {
        return cdgymj;
    }

    public void setCdgymj(Float cdgymj) {
        this.cdgymj = cdgymj;
    }

    public String getSfphgzc() {
        return sfphgzc;
    }

    public void setSfphgzc(String sfphgzc) {
        this.sfphgzc = sfphgzc;
    }

    public String getCdgybz() {
        return cdgybz;
    }

    public void setCdgybz(String cdgybz) {
        this.cdgybz = cdgybz;
    }

    public Float getWtyymj() {
        return wtyymj;
    }

    public void setWtyymj(Float wtyymj) {
        this.wtyymj = wtyymj;
    }

    public String getWtyybz() {
        return wtyybz;
    }

    public void setWtyybz(String wtyybz) {
        this.wtyybz = wtyybz;
    }

    public String getSsbs() {
        return ssbs;
    }

    public void setSsbs(String ssbs) {
        this.ssbs = ssbs;
    }

    public Float getTsyzmj() {
        return tsyzmj;
    }

    public void setTsyzmj(Float tsyzmj) {
        this.tsyzmj = tsyzmj;
    }

    public String getSszylx() {
        return sszylx;
    }

    public void setSszylx(String sszylx) {
        this.sszylx = sszylx;
    }

    public Float getSshfyjjsmj() {
        return sshfyjjsmj;
    }

    public void setSshfyjjsmj(Float sshfyjjsmj) {
        this.sshfyjjsmj = sshfyjjsmj;
    }

    public Float getSsffyjjsmj() {
        return ssffyjjsmj;
    }

    public void setSsffyjjsmj(Float ssffyjjsmj) {
        this.ssffyjjsmj = ssffyjjsmj;
    }

    public String getJszylx() {
        return jszylx;
    }

    public void setJszylx(String jszylx) {
        this.jszylx = jszylx;
    }

    public Float getHfyjjsmj() {
        return hfyjjsmj;
    }

    public void setHfyjjsmj(Float hfyjjsmj) {
        this.hfyjjsmj = hfyjjsmj;
    }

    public Float getFfyjjsmj() {
        return ffyjjsmj;
    }

    public void setFfyjjsmj(Float ffyjjsmj) {
        this.ffyjjsmj = ffyjjsmj;
    }

    public Float getLsydzymj() {
        return lsydzymj;
    }

    public void setLsydzymj(Float lsydzymj) {
        this.lsydzymj = lsydzymj;
    }

    public String getJszybz() {
        return jszybz;
    }

    public void setJszybz(String jszybz) {
        this.jszybz = jszybz;
    }

    public Float getZhgdmj() {
        return zhgdmj;
    }

    public void setZhgdmj(Float zhgdmj) {
        this.zhgdmj = zhgdmj;
    }

    public String getZhyy() {
        return zhyy;
    }

    public void setZhyy(String zhyy) {
        this.zhyy = zhyy;
    }

    public String getZhgdbz() {
        return zhgdbz;
    }

    public void setZhgdbz(String zhgdbz) {
        this.zhgdbz = zhgdbz;
    }

    public Float getGfydmj() {
        return gfydmj;
    }

    public void setGfydmj(Float gfydmj) {
        this.gfydmj = gfydmj;
    }

    public Float getGfbgd() {
        return gfbgd;
    }

    public void setGfbgd(Float gfbgd) {
        this.gfbgd = gfbgd;
    }

    public String getGfydbz() {
        return gfydbz;
    }

    public void setGfydbz(String gfydbz) {
        this.gfydbz = gfydbz;
    }

    public Float getQtydmj() {
        return qtydmj;
    }

    public void setQtydmj(Float qtydmj) {
        this.qtydmj = qtydmj;
    }

    public String getQtydbz() {
        return qtydbz;
    }

    public void setQtydbz(String qtydbz) {
        this.qtydbz = qtydbz;
    }

    public String getTdzlcun() {
        return tdzlcun;
    }

    public void setTdzlcun(String tdzlcun) {
        this.tdzlcun = tdzlcun;
    }

    public String getTdzlxz() {
        return tdzlxz;
    }

    public void setTdzlxz(String tdzlxz) {
        this.tdzlxz = tdzlxz;
    }

    public String getXzb() {
        return xzb;
    }

    public void setXzb(String xzb) {
        this.xzb = xzb;
    }

    public String getYzb() {
        return yzb;
    }

    public void setYzb(String yzb) {
        this.yzb = yzb;
    }

    public Double getJd() {
        return jd;
    }

    public void setJd(Double jd) {
        this.jd = jd;
    }

    public Double getWd() {
        return wd;
    }

    public void setWd(Double wd) {
        this.wd = wd;
    }

    public Date getSx() {
        return sx;
    }

    public void setSx(Date sx) {
        this.sx = sx;
    }

    public byte[] getTxwkb() {
        return txwkb;
    }

    public void setTxwkb(byte[] txwkb) {
        this.txwkb = txwkb;
    }

    public String getTx() {
        return tx;
    }

    public void setTx(String tx) {
        this.tx = tx;
    }

    public String getYxlj() {
        return yxlj;
    }

    public void setYxlj(String yxlj) {
        this.yxlj = yxlj;
    }

    public String getDkjzzt() {
        return dkjzzt;
    }

    public void setDkjzzt(String dkjzzt) {
        this.dkjzzt = dkjzzt;
    }

    public String getJzry() {
        return jzry;
    }

    public void setJzry(String jzry) {
        this.jzry = jzry;
    }

    public Date getJzsj() {
        return jzsj;
    }

    public void setJzsj(Date jzsj) {
        this.jzsj = jzsj;
    }

    public byte[] getJzqm() {
        return jzqm;
    }

    public void setJzqm(byte[] jzqm) {
        this.jzqm = jzqm;
    }

    public String getSfwy() {
        return sfwy;
    }

    public void setSfwy(String sfwy) {
        this.sfwy = sfwy;
    }

    public Integer getTbpx() {
        return tbpx;
    }

    public void setTbpx(Integer tbpx) {
        this.tbpx = tbpx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getWtbz() {
        return wtbz;
    }

    public void setWtbz(String wtbz) {
        this.wtbz = wtbz;
    }

    public String getXmsjly() {
        return xmsjly;
    }

    public void setXmsjly(String xmsjly) {
        this.xmsjly = xmsjly;
    }
}
